==> eventbus-spring-boot-autoconfigure-0.6.9-sources.jar: me/ahoo/eventbus/spring/boot/autoconfigure/kafka/BusKafkaAutoConfiguration.java <==
package me.ahoo.eventbus.spring.boot.autoconfigure.kafka;

import me.ahoo.eventbus.core.consistency.ConsistencySubscriberFactory;
import me.ahoo.eventbus.core.publisher.Publisher;
import me.ahoo.eventbus.core.subscriber.SubscriberRegistry;
import me.ahoo.eventbus.kafka.KafkaPublisher;
import me.ahoo.eventbus.kafka.KafkaSubscriberRegistry;
import org.springframework.boot.autoconfigure.AutoConfigureAfter;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.kafka.KafkaAutoConfiguration;
import org.springframework.context.annotation.Bean;
import org.springframework.kafka.config.KafkaListenerContainerFactory;
import org.springframework.kafka.config.KafkaListenerEndpointRegistry;
import org.springframework.kafka.core.KafkaTemplate;

/**
 * @author ahoo wang
 * create time 2020/5/14 22:34
 */
@AutoConfigureAfter(KafkaAutoConfiguration.class)
@ConditionalOnClass(KafkaPublisher.class)
public class BusKafkaAutoConfiguration {
    @Bean
    @ConditionalOnMissingBean
    public Publisher publisher(
            KafkaTemplate kafkaTemplate) {
        return new KafkaPublisher(kafkaTemplate);
    }

    @Bean
    @ConditionalOnMissingBean
    public SubscriberRegistry subscribeContainer(
            ConsistencySubscriberFactory consistencySubscriberFactory,
            KafkaListenerEndpointRegistry listenerEndpointRegistry,
            KafkaListenerContainerFactory listenerContainerFactory) {
        return new KafkaSubscriberRegistry(consistencySubscriberFactory,listenerEndpointRegistry, listenerContainerFactory);
    }
}

==> eventbus-spring-boot-autoconfigure-0.8.5-sources.jar: me/ahoo/eventbus/spring/boot/autoconfigure/kafka/BusKafkaAutoConfiguration.java <==
package me.ahoo.eventbus.spring.boot.autoconfigure.kafka;

import me.ahoo.eventbus.core.consistency.ConsistencySubscriberFactory;
import me.ahoo.eventbus.core.publisher.Publisher;
import me.ahoo.eventbus.core.subscriber.SubscriberRegistry;
import me.ahoo.eventbus.kafka.KafkaPublisher;
import me.ahoo.eventbus.kafka.KafkaSubscriberRegistry;
import org.springframework.boot.autoconfigure.AutoConfigureAfter;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.kafka.KafkaAutoConfiguration;
import org.springframework.context.annotation.Bean;
import org.springframework.kafka.config.KafkaListenerContainerFactory;
import org.springframework.kafka.config.KafkaListenerEndpointRegistry;
import org.springframework.kafka.core.KafkaTemplate;

/**
 * @author ahoo wang
 * create time 2020/5/14 22:34
 */
@AutoConfigureAfter(KafkaAutoConfiguration.class)
@ConditionalOnClass(KafkaPublisher.class)
public class BusKafkaAutoConfiguration {
    @Bean
    @ConditionalOnMissingBean
    public Publisher kafkaPublisher(
            KafkaTemplate kafkaTemplate) {
        return new KafkaPublisher(kafkaTemplate);
    }

    @Bean
    @ConditionalOnMissingBean
    public SubscriberRegistry kafkaSubscriberRegistry(
            ConsistencySubscriberFactory consistencySubscriberFactory,
            KafkaListenerEndpointRegistry listenerEndpointRegistry,
            KafkaListenerContainerFactory listenerContainerFactory) {
        return new KafkaSubscriberRegistry(consistencySubscriberFactory,listenerEndpointRegistry, listenerContainerFactory);
    }
}
